
dialogId("sch-m-spadlo", "font_small", "Something fell here again.")
dialogStr("Co nám to sem zase spadlo?")


dialogId("sch-v-lastura", "font_big", "It’s some kind of shell. We’ll probably have to push it upstairs again.")
dialogStr("Nějaká lastura. Asi ji budem muset vystrkat nahoru.")


dialogId("sch-v-setkani", "font_big", "I can see it now: 'Shell Meets Flowerpot’. That’s almost like an iron and a sewing machine meeting on an operating table.")
dialogStr("Setkání lastury s květináčem. To je skoro jako setkání žehličky s šicím strojem na operačním stole.")


dialogId("sch-m-moc0", "font_small", "I’m sorry, I got a bit carried away.")
dialogStr("Nějak jsem se do toho moc zabrala.")


dialogId("sch-m-moc1", "font_small", "Sorry, I was momentarily distracted.")
dialogStr("Na chvíli jsem se zamyslela.")


dialogId("sch-m-moc2", "font_small", "Where I am going with this shell?")
dialogStr("Kam to vlastně strkám?")

